using System;
using System.Collections.Generic;
using System.Text;
using Persistate;
using DeviceNetwork.Model;

namespace DeviceNetwork.Desktop
{
	/// <summary>
	/// This static class contains user interface methods for the 
	///  View operation group.
	/// </summary>
	/// <remarks>
	/// These will include IsEnabled methods, and also Execute
	/// methods for any operations defined as user interface
	/// operations.
	/// </remarks>
	public static class ViewOperations
	{
		/// <summary>
		/// Determines whether the Back operation should be enabled and/or
		/// visible for a particular potential target Persistent.
		/// </summary>
		/// <param name="session">The session requesting whether the operation
		/// should be enabled and/or visible.</param>
		/// <param name="target">The Persistent on which any Execute call
		/// would be made.</param>
		/// <param name="collection">Any collection involved with this
		/// operation.</param>
		/// <returns>A value indicating whether the operation should be enabled
		/// and/or visible.</returns>
		public static OperationPresence BackPresence(Session session, Persistent target, 
			IPersistateList collection)
		{
			return StandardOperations.BackPresence(session, target, collection);
		}


		/// <summary>
		/// Executes the Back operation in the 
		/// View group.
		/// </summary>
		/// <param name="execution">The operation Execution object created for the
		/// execution of the Back operation.</param>
		/// <returns>An ExecutionResult which should be set with the result
		/// of the operation.</returns>
		public static ExecutionResult ExecuteBack(Execution execution)
		{
			return StandardOperations.ExecuteBack(execution);
		}

		/// <summary>
		/// Determines whether the Forward operation should be enabled and/or
		/// visible for a particular potential target Persistent.
		/// </summary>
		/// <param name="session">The session requesting whether the operation
		/// should be enabled and/or visible.</param>
		/// <param name="target">The Persistent on which any Execute call
		/// would be made.</param>
		/// <param name="collection">Any collection involved with this
		/// operation.</param>
		/// <returns>A value indicating whether the operation should be enabled
		/// and/or visible.</returns>
		public static OperationPresence ForwardPresence(Session session, Persistent target, 
			IPersistateList collection)
		{
			return StandardOperations.ForwardPresence(session, target, collection);
		}


		/// <summary>
		/// Executes the Forward operation in the 
		/// View group.
		/// </summary>
		/// <param name="execution">The operation Execution object created for the
		/// execution of the Forward operation.</param>
		/// <returns>An ExecutionResult which should be set with the result
		/// of the operation.</returns>
		public static ExecutionResult ExecuteForward(Execution execution)
		{
			return StandardOperations.ExecuteForward(execution);
		}

		/// <summary>
		/// Determines whether the Parent operation should be enabled and/or
		/// visible for a particular potential target Persistent.
		/// </summary>
		/// <param name="session">The session requesting whether the operation
		/// should be enabled and/or visible.</param>
		/// <param name="target">The Persistent on which any Execute call
		/// would be made.</param>
		/// <param name="collection">Any collection involved with this
		/// operation.</param>
		/// <returns>A value indicating whether the operation should be enabled
		/// and/or visible.</returns>
		public static OperationPresence ParentPresence(Session session, Persistent target, 
			IPersistateList collection)
		{
			return StandardOperations.ParentPresence(session, target, collection);
		}


		/// <summary>
		/// Determines whether the Save workspace operation should be enabled and/or
		/// visible for a particular potential target Persistent.
		/// </summary>
		/// <param name="session">The session requesting whether the operation
		/// should be enabled and/or visible.</param>
		/// <param name="target">The Persistent on which any Execute call
		/// would be made.</param>
		/// <param name="collection">Any collection involved with this
		/// operation.</param>
		/// <returns>A value indicating whether the operation should be enabled
		/// and/or visible.</returns>
		public static OperationPresence SaveWorkspacePresence(Session session, Persistent target, 
			IPersistateList collection)
		{
			return StandardOperations.SaveWorkspacePresence(session, target, collection);
		}


		/// <summary>
		/// Determines whether the Restore workspace operation should be enabled and/or
		/// visible for a particular potential target Persistent.
		/// </summary>
		/// <param name="session">The session requesting whether the operation
		/// should be enabled and/or visible.</param>
		/// <param name="target">The Persistent on which any Execute call
		/// would be made.</param>
		/// <param name="collection">Any collection involved with this
		/// operation.</param>
		/// <returns>A value indicating whether the operation should be enabled
		/// and/or visible.</returns>
		public static OperationPresence RestoreWorkspacePresence(Session session, Persistent target, 
			IPersistateList collection)
		{
			return StandardOperations.RestoreWorkspacePresence(session, target, collection);
		}


		/// <summary>
		/// Determines whether the Select container operation should be enabled and/or
		/// visible for a particular potential target Persistent.
		/// </summary>
		/// <param name="session">The session requesting whether the operation
		/// should be enabled and/or visible.</param>
		/// <param name="target">The Persistent on which any Execute call
		/// would be made.</param>
		/// <param name="collection">Any collection involved with this
		/// operation.</param>
		/// <returns>A value indicating whether the operation should be enabled
		/// and/or visible.</returns>
		public static OperationPresence SelectContainerPresence(Session session, Persistent target, 
			IPersistateList collection)
		{
			return StandardOperations.SelectContainerPresence(session, target, collection);
		}


		/// <summary>
		/// Executes the Select container operation in the 
		/// View group.
		/// </summary>
		/// <param name="execution">The operation Execution object created for the
		/// execution of the Select container operation.</param>
		/// <returns>An ExecutionResult which should be set with the result
		/// of the operation.</returns>
		public static ExecutionResult ExecuteSelectContainer(Execution execution)
		{
			return StandardOperations.ExecuteSelectContainer(execution);
		}

		/// <summary>
		/// Determines whether the Add tab operation should be enabled and/or
		/// visible for a particular potential target Persistent.
		/// </summary>
		/// <param name="session">The session requesting whether the operation
		/// should be enabled and/or visible.</param>
		/// <param name="target">The Persistent on which any Execute call
		/// would be made.</param>
		/// <param name="collection">Any collection involved with this
		/// operation.</param>
		/// <returns>A value indicating whether the operation should be enabled
		/// and/or visible.</returns>
		public static OperationPresence AddTabPresence(Session session, Persistent target, 
			IPersistateList collection)
		{
			return StandardOperations.AddTabPresence(session, target, collection);
		}


		/// <summary>
		/// Executes the Add tab operation in the 
		/// View group.
		/// </summary>
		/// <param name="execution">The operation Execution object created for the
		/// execution of the Add tab operation.</param>
		/// <returns>An ExecutionResult which should be set with the result
		/// of the operation.</returns>
		public static ExecutionResult ExecuteAddTab(Execution execution)
		{
			return StandardOperations.ExecuteAddTab(execution);
		}

		/// <summary>
		/// Determines whether the Apply style operation should be enabled and/or
		/// visible for a particular potential target Persistent.
		/// </summary>
		/// <param name="session">The session requesting whether the operation
		/// should be enabled and/or visible.</param>
		/// <param name="target">The Persistent on which any Execute call
		/// would be made.</param>
		/// <param name="collection">Any collection involved with this
		/// operation.</param>
		/// <returns>A value indicating whether the operation should be enabled
		/// and/or visible.</returns>
		public static OperationPresence ApplyStylePresence(Session session, Persistent target, 
			IPersistateList collection)
		{
			return StandardOperations.ApplyStylePresence(session, target, collection);
		}


		/// <summary>
		/// Executes the Apply style operation in the 
		/// View group.
		/// </summary>
		/// <param name="execution">The operation Execution object created for the
		/// execution of the Apply style operation.</param>
		/// <returns>An ExecutionResult which should be set with the result
		/// of the operation.</returns>
		public static ExecutionResult ExecuteApplyStyle(Execution execution)
		{
			return StandardOperations.ExecuteApplyStyle(execution);
		}

		/// <summary>
		/// Determines whether the Maintain workspaces operation should be enabled and/or
		/// visible for a particular potential target Persistent.
		/// </summary>
		/// <param name="session">The session requesting whether the operation
		/// should be enabled and/or visible.</param>
		/// <param name="target">The Persistent on which any Execute call
		/// would be made.</param>
		/// <param name="collection">Any collection involved with this
		/// operation.</param>
		/// <returns>A value indicating whether the operation should be enabled
		/// and/or visible.</returns>
		public static OperationPresence MaintainWorkspacesPresence(Session session, Persistent target, 
			IPersistateList collection)
		{
			return StandardOperations.MaintainWorkspacesPresence(session, target, collection);
		}


	}
}
